#include "MainWindow.h"

#include <QString>
#include <QList>
#include <QLabel>

//kde specific includes
#include <kcomponentdata.h>
#include <kcmdlineargs.h>
#include <klocale.h>
#include <kdebug.h>

#include <iostream>

MainWindow::MainWindow(QWidget *parent) : KXmlGuiWindow(parent), m_fileView(this), m_media(0)
{
	// Preration of the file interaction widget
	setCentralWidget(&m_fileView);
	m_fileView.setModel(&m_model);
	m_fileView.setFrameStyle(QFrame::NoFrame);

	// Signal/Slot connection. When a files is selected, it is passed to the slot "play"
	connect(&m_fileView, SIGNAL(updatePreviewWidget(const QModelIndex &)), SLOT(play(const QModelIndex &)));
	
	setupGUI();
}

void MainWindow::play(const QModelIndex &index)
{
	delayedInit();
	m_media->setCurrentSource(m_model.filePath(index));
	m_media->play();
}

void MainWindow::delayedInit()
{
    if (!m_media) {
	// Creating a new Dialog to present the video
        dialog = new KDialog(this);
	dialog->setCaption( "Video" );
	dialog->setButtons( KDialog::Ok );
	// Creating the widget that presents video.
	videoWidget =  new Phonon::VideoWidget(dialog);
	// Asigning the Video Widget as the Main widget in the new dialog, and show it.
	dialog->setMainWidget( videoWidget );
	dialog->show();

	// Creating the MediaObject to handle media files.
	m_media = new Phonon::MediaObject(this);
	// Creating and selecting automatically an Audio Output
        Phonon::AudioOutput *audioOutput = new Phonon::AudioOutput(Phonon::VideoCategory, this);
	
	// Connecting through Phonon Paths, the audio and video output, to the corresponding objects.
	Phonon::createPath(m_media, audioOutput);
	Phonon::createPath(m_media, videoWidget);

	
    }
}

// #include "build/mediaplayer_automoc.cpp"
