#include "MainWindow.h"

#include <QString>
#include <QList>

//solid specific includes
#include <solid/devicenotifier.h>
#include <solid/device.h>
#include <solid/deviceinterface.h>
#include <solid/storageaccess.h>

//kde specific includes
#include <kcomponentdata.h>
#include <kcmdlineargs.h>
#include <klocale.h>
#include <kdebug.h>
#include <QLabel>

#include <iostream>

MainWindow::MainWindow(QWidget *parent) : KXmlGuiWindow(parent), m_fileView(this), m_media(0)
{
	dialog = NULL;

	// Preration of the file interaction widget
	setCentralWidget(&m_fileView);
	m_fileView.setModel(&m_model);
	m_fileView.setFrameStyle(QFrame::NoFrame);

	// Signal/Slot connection. When a files is selected, it is passed to the slot "play"
	connect(&m_fileView, SIGNAL(updatePreviewWidget(const QModelIndex &)), SLOT(play(const QModelIndex &)));
	
	// Obtaining Solid Notifier Instance
	DeviceNotifier = Solid::DeviceNotifier().instance();

	kDebug() << "Creating SIGNAL/SLOT connections";
	// Signal/Slot connection. When a new device is plugged, it is passed to the slot "newMedia"
	connect(DeviceNotifier, SIGNAL(deviceAdded(const QString &)), SLOT(newMedia(const QString &)));

	setupGUI();
}

void MainWindow::play(const QModelIndex &index)
{
	delayedInit();
	m_media->setCurrentSource(m_model.filePath(index));
	m_media->play();
}

void MainWindow::newMedia(const QString &udi){
	kDebug() << "Nuevo dispositivo encontrado";
	foreach (Solid::Device device, Solid::Device::listFromType(Solid::DeviceInterface::StorageAccess, QString())){
		if( udi == device.udi() ){
			kDebug() << device.udi().toLatin1().constData();
			kDebug() << device.product();

// 			Device = device.asDeviceInterface(Solid::DeviceInterface::StorageAccess);
			Device = device.as<Solid::StorageAccess>();
			connect( Device, SIGNAL( setupDone(Solid::ErrorType, QVariant, const QString &)), SLOT( mountDone(Solid::ErrorType, QVariant, const QString &)));

			KDialog *deviceDialog = new KDialog(this);
			deviceDialog->setCaption( i18n("Nuevo dispositivo detectado.") );
			QLabel* label = new QLabel( i18n("Se ha detectacto un nuevo dispositivo de almacenamiento. ¿Desea Montarlo?"), deviceDialog );
			deviceDialog->setButtons( KDialog::Ok | KDialog::Cancel );
			deviceDialog->setMainWidget( label ); 
			deviceDialog->show();
			connect( deviceDialog, SIGNAL( okClicked() ), SLOT( mountDevice()));
		}
	}
	
}

void MainWindow::mountDevice(){
	Device->setup();
}

void MainWindow::mountDone(Solid::ErrorType error, QVariant errorData, const QString &udi){
	kDebug() << Device->filePath().toLatin1().constData();
	m_fileView.setRootIndex(m_model.index(Device->filePath()));
}

void MainWindow::delayedInit()
{
	if(dialog == NULL){
		// Creating a new Dialog to present the video
	        dialog = new KDialog(this);
		dialog->setCaption( "Video" );
		dialog->setButtons( KDialog::Ok );

		// Creating the widget that presents video.
		videoWidget =  new Phonon::VideoWidget(dialog);

		// Asigning the Video Widget as the Main widget in the new dialog, and show it.
		dialog->setMainWidget( videoWidget );
	}
	if (!m_media) {
		// Creating the MediaObject to handle media files.
		m_media = new Phonon::MediaObject(this);

		// Creating and selecting automatically an Audio Output
	        Phonon::AudioOutput *audioOutput = new Phonon::AudioOutput(Phonon::VideoCategory, this);
	
		// Connecting through Phonon Paths, the audio and video output, to the corresponding objects.
		Phonon::createPath(m_media, audioOutput);
		Phonon::createPath(m_media, videoWidget);
	}
	dialog->show();
}

// #include "build/mediaplayer_automoc.cpp"
